@@ -1,6 +1,6 @@
 -- The MIT License (MIT)
 
--- Copyright (c) 2013 - 2015 Peter Melnichenko
+-- Copyright (c) 2013 - 2018 Peter Melnichenko
 
 -- Permission is hereby granted, free of charge, to any person obtaining a copy of
 -- this software and associated documentation files (the "Software"), to deal in
@@ -48,7 +48,7 @@ local function class(prototype, properties, parent)
    if properties then
       local names = {}
 
-      -- Create setter methods and fill set of property names. 
+      -- Create setter methods and fill set of property names.
       for _, property in ipairs(properties) do
          local name, callback = property[1], property[2]
 
@@ -232,6 +232,7 @@ local Parser = class({
    _options = {},
    _commands = {},
    _mutexes = {},
+   _groups = {},
    _require_command = true,
    _handle_options = true
 }, {
@@ -245,6 +246,12 @@ local Parser = class({
    typechecked("handle_options", "boolean"),
    typechecked("action", "function"),
    typechecked("command_target", "string"),
+   typechecked("help_vertical_space", "number"),
+   typechecked("usage_margin", "number"),
+   typechecked("usage_max_width", "number"),
+   typechecked("help_usage_margin", "number"),
+   typechecked("help_description_margin", "number"),
+   typechecked("help_max_width", "number"),
    add_help
 })
 
@@ -262,6 +269,13 @@ local Command = class({
    typechecked("handle_options", "boolean"),
    typechecked("action", "function"),
    typechecked("command_target", "string"),
+   typechecked("help_vertical_space", "number"),
+   typechecked("usage_margin", "number"),
+   typechecked("usage_max_width", "number"),
+   typechecked("help_usage_margin", "number"),
+   typechecked("help_description_margin", "number"),
+   typechecked("help_max_width", "number"),
+   typechecked("hidden", "boolean"),
    add_help
 }, Parser)
 
@@ -283,6 +297,7 @@ local Argument = class({
    typechecked("defmode", "string"),
    typechecked("show_default", "boolean"),
    typechecked("argname", "string", "table"),
+   typechecked("hidden", "boolean"),
    option_action,
    option_init
 })
@@ -304,10 +319,29 @@ local Option = class({
    typechecked("show_default", "boolean"),
    typechecked("overwrite", "boolean"),
    typechecked("argname", "string", "table"),
+   typechecked("hidden", "boolean"),
    option_action,
    option_init
 }, Argument)
 
+function Parser:_inherit_property(name, default)
+   local element = self
+
+   while true do
+      local value = element["_" .. name]
+
+      if value ~= nil then
+         return value
+      end
+
+      if not element._parent then
+         return default
+      end
+
+      element = element._parent
+   end
+end
+
 function Argument:_get_argument_list()
    local buf = {}
    local i = 1
@@ -422,7 +456,7 @@ function Argument:_get_action()
    return action, init
 end
 
--- Returns placeholder for `narg`-th argument. 
+-- Returns placeholder for `narg`-th argument.
 function Argument:_get_argname(narg)
    local argname = self._argname or self:_get_default_argname()
 
@@ -441,26 +475,43 @@ function Option:_get_default_argname()
    return "<" .. self:_get_default_target() .. ">"
 end
 
--- Returns label to be shown in the help message. 
-function Argument:_get_label()
-   return self._name
+-- Returns labels to be shown in the help message.
+function Argument:_get_label_lines()
+   return {self._name}
 end
 
-function Option:_get_label()
-   local variants = {}
+function Option:_get_label_lines()
    local argument_list = self:_get_argument_list()
-   table.insert(argument_list, 1, nil)
 
-   for _, alias in ipairs(self._aliases) do
-      argument_list[1] = alias
-      table.insert(variants, table.concat(argument_list, " "))
+   if #argument_list == 0 then
+      -- Don't put aliases for simple flags like `-h` on different lines.
+      return {table.concat(self._aliases, ", ")}
    end
 
-   return table.concat(variants, ", ")
+   local longest_alias_length = -1
+
+   for _, alias in ipairs(self._aliases) do
+      longest_alias_length = math.max(longest_alias_length, #alias)
+   end
+
+   local argument_list_repr = table.concat(argument_list, " ")
+   local lines = {}
+
+   for i, alias in ipairs(self._aliases) do
+      local line = (" "):rep(longest_alias_length - #alias) .. alias .. " " .. argument_list_repr
+
+      if i ~= #self._aliases then
+         line = line .. ","
+      end
+
+      table.insert(lines, line)
+   end
+
+   return lines
 end
 
-function Command:_get_label()
-   return table.concat(self._aliases, ", ")
+function Command:_get_label_lines()
+   return {table.concat(self._aliases, ", ")}
 end
 
 function Argument:_get_description()
@@ -571,17 +622,32 @@ function Parser:command(...)
 end
 
 function Parser:mutex(...)
-   local options = {...}
+   local elements = {...}
 
-   for i, option in ipairs(options) do
-      assert(getmetatable(option) == Option, ("bad argument #%d to 'mutex' (Option expected)"):format(i))
+   for i, element in ipairs(elements) do
+      local mt = getmetatable(element)
+      assert(mt == Option or mt == Argument, ("bad argument #%d to 'mutex' (Option or Argument expected)"):format(i))
    end
 
-   table.insert(self._mutexes, options)
+   table.insert(self._mutexes, elements)
+   return self
+end
+
+function Parser:group(name, ...)
+   assert(type(name) == "string", ("bad argument #1 to 'group' (string expected, got %s)"):format(type(name)))
+
+   local group = {name = name, ...}
+
+   for i, element in ipairs(group) do
+      local mt = getmetatable(element)
+      assert(mt == Option or mt == Argument or mt == Command,
+         ("bad argument #%d to 'group' (Option or Argument or Command expected)"):format(i + 1))
+   end
+
+   table.insert(self._groups, group)
    return self
 end
 
-local max_usage_width = 70
 local usage_welcome = "Usage: "
 
 function Parser:get_usage()
@@ -589,64 +655,120 @@ function Parser:get_usage()
       return self._usage
    end
 
+   local usage_margin = self:_inherit_property("usage_margin", #usage_welcome)
+   local max_usage_width = self:_inherit_property("usage_max_width", 70)
    local lines = {usage_welcome .. self:_get_fullname()}
 
    local function add(s)
       if #lines[#lines]+1+#s <= max_usage_width then
          lines[#lines] = lines[#lines] .. " " .. s
       else
-         lines[#lines+1] = (" "):rep(#usage_welcome) .. s
+         lines[#lines+1] = (" "):rep(usage_margin) .. s
       end
    end
 
-   -- This can definitely be refactored into something cleaner
-   local mutex_options = {}
-   local vararg_mutexes = {}
+   -- Normally options are before positional arguments in usage messages.
+   -- However, vararg options should be after, because they can't be reliable used
+   -- before a positional argument.
+   -- Mutexes come into play, too, and are shown as soon as possible.
+   -- Overall, output usages in the following order:
+   -- 1. Mutexes that don't have positional arguments or vararg options.
+   -- 2. Options that are not in any mutexes and are not vararg.
+   -- 3. Positional arguments - on their own or as a part of a mutex.
+   -- 4. Remaining mutexes.
+   -- 5. Remaining options.
 
-   -- First, put mutexes which do not contain vararg options and remember those which do
-   for _, mutex in ipairs(self._mutexes) do
+   local elements_in_mutexes = {}
+   local added_elements = {}
+   local added_mutexes = {}
+   local argument_to_mutexes = {}
+
+   local function add_mutex(mutex, main_argument)
+      if added_mutexes[mutex] then
+         return
+      end
+
+      added_mutexes[mutex] = true
       local buf = {}
-      local is_vararg = false
 
-      for _, option in ipairs(mutex) do
-         if option:_is_vararg() then
-            is_vararg = true
+      for _, element in ipairs(mutex) do
+         if not element._hidden and not added_elements[element] then
+            if getmetatable(element) == Option or element == main_argument then
+               table.insert(buf, element:_get_usage())
+               added_elements[element] = true
+            end
+         end
+      end
+
+      if #buf == 1 then
+         add(buf[1])
+      elseif #buf > 1 then
+         add("(" .. table.concat(buf, " | ") .. ")")
+      end
+   end
+
+   local function add_element(element)
+      if not element._hidden and not added_elements[element] then
+         add(element:_get_usage())
+         added_elements[element] = true
+      end
+   end
+
+   for _, mutex in ipairs(self._mutexes) do
+      local is_vararg = false
+      local has_argument = false
+
+      for _, element in ipairs(mutex) do
+         if getmetatable(element) == Option then
+            if element:_is_vararg() then
+               is_vararg = true
+            end
+         else
+            has_argument = true
+            argument_to_mutexes[element] = argument_to_mutexes[element] or {}
+            table.insert(argument_to_mutexes[element], mutex)
          end
 
-         table.insert(buf, option:_get_usage())
-         mutex_options[option] = true
+         elements_in_mutexes[element] = true
       end
 
-      local repr = "(" .. table.concat(buf, " | ") .. ")"
-
-      if is_vararg then
-         table.insert(vararg_mutexes, repr)
-      else
-         add(repr)
+      if not is_vararg and not has_argument then
+         add_mutex(mutex)
       end
    end
 
-   -- Second, put regular options
    for _, option in ipairs(self._options) do
-      if not mutex_options[option] and not option:_is_vararg() then
-         add(option:_get_usage())
+      if not elements_in_mutexes[option] and not option:_is_vararg() then
+         add_element(option)
       end
    end
 
-   -- Put positional arguments
+   -- Add usages for positional arguments, together with one mutex containing them, if they are in a mutex.
    for _, argument in ipairs(self._arguments) do
-      add(argument:_get_usage())
+      -- Pick a mutex as a part of which to show this argument, take the first one that's still available.
+      local mutex
+
+      if elements_in_mutexes[argument] then
+         for _, argument_mutex in ipairs(argument_to_mutexes[argument]) do
+            if not added_mutexes[argument_mutex] then
+               mutex = argument_mutex
+            end
+         end
+      end
+
+      if mutex then
+         add_mutex(mutex, argument)
+      else
+         add_element(argument)
+      end
    end
 
-   -- Put mutexes containing vararg options
-   for _, mutex_repr in ipairs(vararg_mutexes) do
-      add(mutex_repr)
+   for _, mutex in ipairs(self._mutexes) do
+      add_mutex(mutex)
    end
 
    for _, option in ipairs(self._options) do
-      if not mutex_options[option] and option:_is_vararg() then
-         add(option:_get_usage())
-      end
+      add_element(option)
    end
 
    if #self._commands > 0 then
@@ -662,22 +784,173 @@ function Parser:get_usage()
    return table.concat(lines, "\n")
 end
 
-local margin_len = 3
-local margin_len2 = 25
-local margin = (" "):rep(margin_len)
-local margin2 = (" "):rep(margin_len2)
-
-local function make_two_columns(s1, s2)
-   if s2 == "" then
-      return margin .. s1
+local function split_lines(s)
+   if s == "" then
+      return {}
    end
 
-   s2 = s2:gsub("\n", "\n" .. margin2)
+   local lines = {}
 
-   if #s1 < (margin_len2-margin_len) then
-      return margin .. s1 .. (" "):rep(margin_len2-margin_len-#s1) .. s2
+   if s:sub(-1) ~= "\n" then
+      s = s .. "\n"
+   end
+
+   for line in s:gmatch("([^\n]*)\n") do
+      table.insert(lines, line)
+   end
+
+   return lines
+end
+
+local function autowrap_line(line, max_length)
+   -- Algorithm for splitting lines is simple and greedy.
+   local result_lines = {}
+
+   -- Preserve original indentation of the line, put this at the beginning of each result line.
+   -- If the first word looks like a list marker ('*', '+', or '-'), add spaces so that starts
+   -- of the second and the following lines vertically align with the start of the second word.
+   local indentation = line:match("^ *")
+
+   if line:find("^ *[%*%+%-]") then
+      indentation = indentation .. " " .. line:match("^ *[%*%+%-]( *)")
+   end
+
+   -- Parts of the last line being assembled.
+   local line_parts = {}
+
+   -- Length of the current line.
+   local line_length = 0
+
+   -- Index of the next character to consider.
+   local index = 1
+
+   while true do
+      local word_start, word_finish, word = line:find("([^ ]+)", index)
+
+      if not word_start then
+         -- Ignore trailing spaces, if any.
+         break
+      end
+
+      local preceding_spaces = line:sub(index, word_start - 1)
+      index = word_finish + 1
+
+      if (#line_parts == 0) or (line_length + #preceding_spaces + #word <= max_length) then
+         -- Either this is the very first word or it fits as an addition to the current line, add it.
+         table.insert(line_parts, preceding_spaces) -- For the very first word this adds the indentation.
+         table.insert(line_parts, word)
+         line_length = line_length + #preceding_spaces + #word
+      else
+         -- Does not fit, finish current line and put the word into a new one.
+         table.insert(result_lines, table.concat(line_parts))
+         line_parts = {indentation, word}
+         line_length = #indentation + #word
+      end
+   end
+
+   if #line_parts > 0 then
+      table.insert(result_lines, table.concat(line_parts))
+   end
+
+   if #result_lines == 0 then
+      -- Preserve empty lines.
+      result_lines[1] = ""
+   end
+
+   return result_lines
+end
+
+-- Automatically wraps lines within given array,
+-- attempting to limit line length to `max_length`.
+-- Existing line splits are preserved.
+local function autowrap(lines, max_length)
+   local result_lines = {}
+
+   for _, line in ipairs(lines) do
+      local autowrapped_lines = autowrap_line(line, max_length)
+
+      for _, autowrapped_line in ipairs(autowrapped_lines) do
+         table.insert(result_lines, autowrapped_line)
+      end
+   end
+
+   return result_lines
+end
+
+function Parser:_get_element_help(element)
+   local label_lines = element:_get_label_lines()
+   local description_lines = split_lines(element:_get_description())
+
+   local result_lines = {}
+
+   -- All label lines should have the same length (except the last one, it has no comma).
+   -- If too long, start description after all the label lines.
+   -- Otherwise, combine label and description lines.
+
+   local usage_margin_len = self:_inherit_property("help_usage_margin", 3)
+   local usage_margin = (" "):rep(usage_margin_len)
+   local description_margin_len = self:_inherit_property("help_description_margin", 25)
+   local description_margin = (" "):rep(description_margin_len)
+
+   local help_max_width = self:_inherit_property("help_max_width")
+
+   if help_max_width then
+      local description_max_width = math.max(help_max_width - description_margin_len, 10)
+      description_lines = autowrap(description_lines, description_max_width)
+   end
+
+   if #label_lines[1] >= (description_margin_len - usage_margin_len) then
+      for _, label_line in ipairs(label_lines) do
+         table.insert(result_lines, usage_margin .. label_line)
+      end
+
+      for _, description_line in ipairs(description_lines) do
+         table.insert(result_lines, description_margin .. description_line)
+      end
    else
-      return margin .. s1 .. "\n" .. margin2 .. s2
+      for i = 1, math.max(#label_lines, #description_lines) do
+         local label_line = label_lines[i]
+         local description_line = description_lines[i]
+
+         local line = ""
+
+         if label_line then
+            line = usage_margin .. label_line
+         end
+
+         if description_line and description_line ~= "" then
+            line = line .. (" "):rep(description_margin_len - #line) .. description_line
+         end
+
+         table.insert(result_lines, line)
+      end
+   end
+
+   return table.concat(result_lines, "\n")
+end
+
+local function get_group_types(group)
+   local types = {}
+
+   for _, element in ipairs(group) do
+      types[getmetatable(element)] = true
+   end
+
+   return types
+end
+
+function Parser:_add_group_help(blocks, added_elements, label, elements)
+   local buf = {label}
+
+   for _, element in ipairs(elements) do
+      if not element._hidden and not added_elements[element] then
+         added_elements[element] = true
+         table.insert(buf, self:_get_element_help(element))
+      end
+   end
+
+   if #buf > 1 then
+      table.insert(blocks, table.concat(buf, ("\n"):rep(self:_inherit_property("help_vertical_space", 0) + 1)))
    end
 end
 
@@ -687,27 +960,72 @@ function Parser:get_help()
    end
 
    local blocks = {self:get_usage()}
-   
+
+   local help_max_width = self:_inherit_property("help_max_width")
+
    if self._description then
-      table.insert(blocks, self._description)
+      local description = self._description
+
+      if help_max_width then
+         description = table.concat(autowrap(split_lines(description), help_max_width), "\n")
+      end
+
+      table.insert(blocks, description)
    end
 
-   local labels = {"Arguments:", "Options:", "Commands:"}
+   -- 1. Put groups containing arguments first, then other arguments.
+   -- 2. Put remaining groups containing options, then other options.
+   -- 3. Put remaining groups containing commands, then other commands.
+   -- Assume that an element can't be in several groups.
+   local groups_by_type = {
+      [Argument] = {},
+      [Option] = {},
+      [Command] = {}
+   }
 
-   for i, elements in ipairs{self._arguments, self._options, self._commands} do
-      if #elements > 0 then
-         local buf = {labels[i]}
+   for _, group in ipairs(self._groups) do
+      local group_types = get_group_types(group)
 
-         for _, element in ipairs(elements) do
-            table.insert(buf, make_two_columns(element:_get_label(), element:_get_description()))
+      for _, mt in ipairs({Argument, Option, Command}) do
+         if group_types[mt] then
+            table.insert(groups_by_type[mt], group)
+            break
          end
-
-         table.insert(blocks, table.concat(buf, "\n"))
       end
    end
 
+   local default_groups = {
+      {name = "Arguments", type = Argument, elements = self._arguments},
+      {name = "Options", type = Option, elements = self._options},
+      {name = "Commands", type = Command, elements = self._commands}
+   }
+
+   local added_elements = {}
+
+   for _, default_group in ipairs(default_groups) do
+      local type_groups = groups_by_type[default_group.type]
+
+      for _, group in ipairs(type_groups) do
+         self:_add_group_help(blocks, added_elements, group.name .. ":", group)
+      end
+
+      local default_label = default_group.name .. ":"
+
+      if #type_groups > 0 then
+         default_label = "Other " .. default_label:gsub("^.", string.lower)
+      end
+
+      self:_add_group_help(blocks, added_elements, default_label, default_group.elements)
+   end
+
    if self._epilog then
-      table.insert(blocks, self._epilog)
+      local epilog = self._epilog
+
+      if help_max_width then
+         epilog = table.concat(autowrap(split_lines(epilog), help_max_width), "\n")
+      end
+
+      table.insert(blocks, epilog)
    end
 
    return table.concat(blocks, "\n\n")
@@ -781,7 +1099,7 @@ function ElementState:error(fmt, ...)
    self.state:error(fmt, ...)
 end
 
-function ElementState:convert(argument)
+function ElementState:convert(argument, index)
    local converter = self.element._convert
 
    if converter then
@@ -789,6 +1107,8 @@ function ElementState:convert(argument)
 
       if type(converter) == "function" then
          ok, err = converter(argument)
+      elseif type(converter[index]) == "function" then
+         ok, err = converter[index](argument)
       else
          ok = converter[argument]
       end
@@ -818,16 +1138,20 @@ local function bound(noun, min, max, is_max)
    return res .. tostring(number) .. " " .. noun ..  (number == 1 and "" or "s")
 end
 
-function ElementState:invoke(alias)
-   self.open = true
+function ElementState:set_name(alias)
    self.name = ("%s '%s'"):format(alias and "option" or "argument", alias or self.element._name)
+end
+
+function ElementState:invoke()
+   self.open = true
    self.overwrite = false
 
    if self.invocations >= self.element._maxcount then
       if self.element._overwrite then
          self.overwrite = true
       else
-         self:error("%s must be used %s", self.name, bound("time", self.element._mincount, self.element._maxcount, true))
+         local num_times_repr = bound("time", self.element._mincount, self.element._maxcount, true)
+         self:error("%s must be used %s", self.name, num_times_repr)
       end
    else
       self.invocations = self.invocations + 1
@@ -843,7 +1167,7 @@ function ElementState:invoke(alias)
 end
 
 function ElementState:pass(argument)
-   argument = self:convert(argument)
+   argument = self:convert(argument, #self.args + 1)
    table.insert(self.args, argument)
 
    if #self.args >= self.element._maxargs then
@@ -879,13 +1203,17 @@ function ElementState:close()
          end
       end
 
-      local args = self.args
+      local args
 
-      if self.element._maxargs <= 1 then
-         args = args[1]
-      end
-
-      if self.element._maxargs == 1 and self.element._minargs == 0 and self.element._mincount ~= self.element._maxcount then
+      if self.element._maxargs == 0 then
+         args = self.args[1]
+      elseif self.element._maxargs == 1 then
+         if self.element._minargs == 0 and self.element._mincount ~= self.element._maxcount then
+            args = self.args
+         else
+            args = self.args[1]
+         end
+      else
          args = self.args
       end
 
@@ -899,7 +1227,7 @@ local ParseState = class({
    arguments = {},
    argument_i = 1,
    element_to_mutexes = {},
-   mutex_to_used_option = {},
+   mutex_to_element_state = {},
    command_actions = {}
 })
 
@@ -932,18 +1260,19 @@ function ParseState:switch(parser)
    end
 
    for _, mutex in ipairs(parser._mutexes) do
-      for _, option in ipairs(mutex) do
-         if not self.element_to_mutexes[option] then
-            self.element_to_mutexes[option] = {}
+      for _, element in ipairs(mutex) do
+         if not self.element_to_mutexes[element] then
+            self.element_to_mutexes[element] = {}
          end
 
-         table.insert(self.element_to_mutexes[option], mutex)
+         table.insert(self.element_to_mutexes[element], mutex)
       end
    end
 
    for _, argument in ipairs(parser._arguments) do
       argument = ElementState(self, argument)
       table.insert(self.arguments, argument)
+      argument:set_name()
       argument:invoke()
    end
 
@@ -982,22 +1311,26 @@ function ParseState:get_command(name)
    end
 end
 
-function ParseState:invoke(option, name)
-   self:close()
+function ParseState:check_mutexes(element_state)
+   if self.element_to_mutexes[element_state.element] then
+      for _, mutex in ipairs(self.element_to_mutexes[element_state.element]) do
+         local used_element_state = self.mutex_to_element_state[mutex]
 
-   if self.element_to_mutexes[option.element] then
-      for _, mutex in ipairs(self.element_to_mutexes[option.element]) do
-         local used_option = self.mutex_to_used_option[mutex]
-
-         if used_option and used_option ~= option then
-            self:error("option '%s' can not be used together with %s", name, used_option.name)
+         if used_element_state and used_element_state ~= element_state then
+            self:error("%s can not be used together with %s", element_state.name, used_element_state.name)
          else
-            self.mutex_to_used_option[mutex] = option
+            self.mutex_to_element_state[mutex] = element_state
          end
       end
    end
+end
 
-   if option:invoke(name) then
+function ParseState:invoke(option, name)
+   self:close()
+   option:set_name(name)
+   self:check_mutexes(option, name)
+
+   if option:invoke() then
       self.option = option
    end
 end
@@ -1008,6 +1341,8 @@ function ParseState:pass(arg)
          self.option = nil
       end
    elseif self.argument then
+      self:check_mutexes(self.argument)
+
       if not self.argument:pass(arg) then
          self.argument_i = self.argument_i + 1
          self.argument = self.arguments[self.argument_i]
@@ -1048,11 +1383,11 @@ function ParseState:finalize()
    end
 
    for _, option in ipairs(self.options) do
-      local name = option.name or ("option '%s'"):format(option.element._name)
+      option.name = option.name or ("option '%s'"):format(option.element._name)
 
       if option.invocations == 0 then
          if option:default("u") then
-            option:invoke(name)
+            option:invoke()
             option:complete_invocation()
             option:close()
          end
@@ -1063,13 +1398,13 @@ function ParseState:finalize()
       if option.invocations < mincount then
          if option:default("a") then
             while option.invocations < mincount do
-               option:invoke(name)
+               option:invoke()
                option:close()
             end
          elseif option.invocations == 0 then
-            self:error("missing %s", name)
+            self:error("missing %s", option.name)
          else
-            self:error("%s must be used %s", name, bound("time", mincount, option.element._maxcount))
+            self:error("%s must be used %s", option.name, bound("time", mincount, option.element._maxcount))
          end
       end
    end
@@ -1092,7 +1427,13 @@ function ParseState:parse(args)
 
                if arg:sub(2, 2) == first then
                   if #arg == 2 then
-                     self:close()
+                     if self.options[arg] then
+                        local option = self:get_option(arg)
+                        self:invoke(option, arg)
+                     else
+                        self:close()
+                     end
+
                      self.handle_options = false
                   else
                      local equals = arg:find "="
@@ -1175,6 +1516,12 @@ function Parser:pparse(args)
    end
 end
 
-return function(...)
+local argparse = {}
+
+argparse.version = "0.6.0"
+
+setmetatable(argparse, {__call = function(_, ...)
    return Parser(default_cmdline[0]):add_help(true)(...)
-end
+end})
+
+return argparse
